@@ -164,19 +164,22 @@ ev_transition_animation_class_init (EvTransitionAnimationClass *klass)
 							      "Effect",
 							      "Transition effect description",
 							      EV_TYPE_TRANSITION_EFFECT,
-							      G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
+							      G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE |
+                                                              G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (object_class,
 					 PROP_ORIGIN_SURFACE,
 					 g_param_spec_pointer ("origin-surface",
 							       "Origin surface",
 							       "Cairo surface from which the animation will happen",
-							       G_PARAM_READWRITE));
+							       G_PARAM_READWRITE |
+                                                               G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (object_class,
 					 PROP_DEST_SURFACE,
 					 g_param_spec_pointer ("dest-surface",
 							       "Destination surface",
 							       "Cairo surface to which the animation will happen",
-							       G_PARAM_READWRITE));
+							       G_PARAM_READWRITE |
+                                                               G_PARAM_STATIC_STRINGS));
 
 	g_type_class_add_private (klass, sizeof (EvTransitionAnimationPriv));
 }
